@@ -121,6 +121,10 @@ class ConfigManager:
                                 self.config.testops.run.set_tags(
                                     [tag.strip() for tag in run.get("tags")])
 
+                            if run.get("externalLink"):
+                                self.config.testops.run.set_external_link(
+                                    run.get("externalLink"))
+
                         if testops.get("batch"):
                             batch = testops.get("batch")
 
@@ -142,6 +146,14 @@ class ConfigManager:
                                 self.config.testops.configurations.set_create_if_not_exists(
                                     configurations.get("createIfNotExists"))
 
+                        if testops.get("statusFilter"):
+                            status_filter = testops.get("statusFilter")
+                            if isinstance(status_filter, list):
+                                self.config.testops.set_status_filter(status_filter)
+                            elif isinstance(status_filter, str):
+                                # Parse comma-separated string
+                                self.config.testops.set_status_filter([s.strip() for s in status_filter.split(',')])
+
                     if config.get("report"):
                         report = config.get("report")
 
@@ -246,6 +258,18 @@ class ConfigManager:
                     self.config.testops.run.set_tags(
                         [tag.strip() for tag in value.split(',')])
 
+                if key == 'QASE_TESTOPS_RUN_EXTERNAL_LINK_TYPE':
+                    if not self.config.testops.run.external_link:
+                        from .models.external_link import ExternalLinkConfig
+                        self.config.testops.run.external_link = ExternalLinkConfig()
+                    self.config.testops.run.external_link.set_type(value)
+
+                if key == 'QASE_TESTOPS_RUN_EXTERNAL_LINK_URL':
+                    if not self.config.testops.run.external_link:
+                        from .models.external_link import ExternalLinkConfig
+                        self.config.testops.run.external_link = ExternalLinkConfig()
+                    self.config.testops.run.external_link.set_link(value)
+
                 if key == 'QASE_TESTOPS_BATCH_SIZE':
                     self.config.testops.batch.set_size(value)
 
@@ -262,6 +286,10 @@ class ConfigManager:
                 if key == 'QASE_TESTOPS_CONFIGURATIONS_CREATE_IF_NOT_EXISTS':
                     self.config.testops.configurations.set_create_if_not_exists(value)
 
+                if key == 'QASE_TESTOPS_STATUS_FILTER':
+                    # Parse comma-separated string
+                    self.config.testops.set_status_filter([s.strip() for s in value.split(',')])
+
                 if key == 'QASE_REPORT_DRIVER':
                     self.config.report.set_driver(value)
 
